@@ -1,5 +1,10 @@
+import json
+from os import path
+
 from django.forms import Textarea
 
+from version import get_version
+
 
 class FullScreenTextarea(Textarea):
 
@@ -27,12 +32,14 @@ class FullScreenTextarea(Textarea):
         super(FullScreenTextarea, self).__init__(attrs)
 
     class Media:
+
+        version = get_version()
+
         css = {
             'screen': (
                 '//fonts.googleapis.com/css?family=Roboto',
-                'writingfield/writingfield.css',)
+                'writingfield/app.min-{}.css'.format(version))
         }
         js = (
-            'writingfield/mousetrap.min.js',
-            'writingfield/writingfield.js',
+            'writingfield/app.min-{}.js'.format(version),
         )
